# coding: utf-8
"""
Import Data
===========
"""

from __future__ import unicode_literals

import re
import os
import sys
import email
import tempfile
import datetime

from django.conf import settings

from jmb.core.utils.data_import import XlsFile


class ImportData(XlsFile):

    """
    If you are importing an xls file where the column coincide with all or with parts model field, you can map column
    head with field like this:

    1) Set the model:
    ::

        self.model = model.Organisation

    2) Set the fields_map:
    ::

        fields_map = {
            'vat': 'Vat',
            'company_name': 'CompanyName',
        }


    where the keys are model field name and the values are column head (the space are replaced with _).

    """

    def __init__(
            self, model=None, filename=None, file_contents=None,
            auto=False, sheet_index=0, opts=None, *args, **kwargs
    ):
        super(ImportData, self).__init__(filename=filename, file_contents=file_contents,
                                         auto=auto, sheet_index=sheet_index)
        self.model = model
        self.messages = dict()
        self.messages['inserted'] = 0
        self.messages['modified'] = 0
        self.messages['errors'] = []
        self.opts = opts or {}

    def do(self, row, kw, j):
        """
        Method to overwrite for define import behavior.
        With this method is possible to process a single row of file to import. With the row elements is possible do any
        operation on any model, generally add/modify model.
        If you are importing an xls file that add or edit a model you can see a result of operation by keeping the count in
        the variable:
        ::
            def do(self, row, kw, j):
                ...
                self.messages['inserted']
                self.messages['modified']

        If you need to see an error message you can use:
        ::

            def do(self, row, kw, j):
                ...
                self.messages['errors'].append('YOUR ERROR MESSAGE')

        :param row: xls row object. Row element can be taken with row.<column_name> where <column_name> is the unicode
                    and case-sensitive head column (at first row).
        :param kw:  dictionary of mapping column->model.field (if fields_map and relative model is set kw is
                    automatically fill).
        :param j:   row number.
        :return:    what you want.
        """
        raise NotImplementedError("do() method must be implemented")
